@@ -1346,7 +1346,7 @@ video_test_button_clicked_cb (GtkWidget *w,
 		      video_manager, 
 		      video_recorder);
 
-  if (GTK_TOGGLE_BUTTON (w)->active)   
+  if (GTK_TOGGLE_BUTTON (w)->active && video_manager && video_recorder)
     t = new GMVideoTester (video_manager, video_recorder);
 }
 
@@ -1448,6 +1448,7 @@ finish_cb (GnomeDruidPage *p,
   if (account == NULL) {
 
     account = gm_account_new ();
+    account->default_account = TRUE;
     account->account_name = g_strdup ("ekiga.net SIP Service");
     account->host = g_strdup ("ekiga.net");
     account->domain = g_strdup ("ekiga.net");
@@ -1472,24 +1473,24 @@ finish_cb (GnomeDruidPage *p,
   account->enabled =
     !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dw->use_gnomemeeting_net));
 
-  /* If creating a new account, add it only if the user wants to use GM.NET */
+  /* If creating a new account, add it only if the user wants to use GM.NET,
+   * and make it the default account */
   if (new_account) {
    
-    if (account->enabled) {
-      
+    if (account->enabled) 
       gnomemeeting_account_add (account);
-      gnomemeeting_account_set_default (account, TRUE);
-    }
   }
   else { 
 
+    /* Modify the account, do not set it as default */
     gnomemeeting_account_modify (account);
-    gnomemeeting_account_set_default (account, TRUE);
   }
     
   /* Register the current Endpoint to GnomeMeeting.NET */
+  gdk_threads_leave ();
   if (account->enabled)
     ep->Register (account);
+  gdk_threads_enter ();
 
   /* Set the right devices and managers */
   if (audio_manager)
@@ -1547,7 +1548,9 @@ finish_cb (GnomeDruidPage *p,
 
   /* Will be done through the config if the manager changes, but not
      if the manager doesn't change */
+  gdk_threads_leave ();
   GnomeMeeting::Process ()->DetectDevices ();  
+  gdk_threads_enter ();
   
 
   /* Update the version number */
@@ -1759,6 +1762,7 @@ prepare_audio_devices_page_cb (GnomeDruidPage *page,
   
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dw->audio_test_button),
 				FALSE);
+  gtk_widget_set_sensitive (GTK_WIDGET (dw->audio_test_button), TRUE);
   
   if (dw->audio_manager)
     audio_manager = 
@@ -1780,8 +1784,6 @@ prepare_audio_devices_page_cb (GnomeDruidPage *page,
     devices += PString (_("No device found"));
     gtk_widget_set_sensitive (GTK_WIDGET (dw->audio_test_button), FALSE);
   }
-  else
-    gtk_widget_set_sensitive (GTK_WIDGET (dw->audio_test_button), TRUE);
   
   array = devices.ToCharArray ();
   gm_dw_option_menu_update (dw->audio_player, array, player);
@@ -1794,8 +1796,6 @@ prepare_audio_devices_page_cb (GnomeDruidPage *page,
     devices += PString (_("No device found"));
     gtk_widget_set_sensitive (GTK_WIDGET (dw->audio_test_button), FALSE);
   }
-  else 
-    gtk_widget_set_sensitive (GTK_WIDGET (dw->audio_test_button), TRUE);
   
   array = devices.ToCharArray ();
   gm_dw_option_menu_update (dw->audio_recorder, array, recorder);
